@@ -1,6 +1,6 @@
 from click import command, option
 
-from dagorama.runner import execute
+from dagorama.runner import execute_worker
 
 
 @command()
@@ -8,7 +8,7 @@ from dagorama.runner import execute
 @option("--include-queue", multiple=True)
 @option("--toleration", multiple=True)
 def worker(exclude_queue: list[str], include_queue: list[str], toleration: list[str]):
-    execute(
+    execute_worker(
         exclude_queues=exclude_queue,
         include_queues=include_queue,
         queue_tolerations=toleration,
