@@ -2,7 +2,7 @@ from inspect import getfullargspec
 
 from dagorama.decorators import dagorama
 from dagorama.definition import DAGDefinition, resolve
-from dagorama.runner import execute, execute_async
+from dagorama.runner import execute_worker, execute_worker_async
 from dagorama.serializer import register_definition
 
 
@@ -26,7 +26,7 @@ def test_runner_custom_init(broker):
     dag_instance, dag_result = dag()
 
     register_definition(dag)
-    execute(infinite_loop=False, catch_exceptions=False)
+    execute_worker(infinite_loop=False, catch_exceptions=False)
 
     assert resolve(dag_instance, dag_result) == 10
 
@@ -36,6 +36,6 @@ def test_sync_async_parity():
     Ensure the sync and async runner functions have the same API.
 
     """
-    sync_spec = getfullargspec(execute)
-    async_spec = getfullargspec(execute_async)
+    sync_spec = getfullargspec(execute_worker)
+    async_spec = getfullargspec(execute_worker_async)
     assert sync_spec.args == async_spec.args
